Tuple9<T0, T1, T2, T3, T4, T5, T6, T7, T8> class
A finite fixed-length ordered list containing 9 dynamically-typed elements.
- Inheritance
- Available extensions
- AggregateExtension
- AggregateRightExtension
- AggregateRightSelectExtension
- AggregateSelectExtension
- AllExtension
- AppendAllExtension
- AppendExtension
- AssertAllExtension
- AssertAnyExtension
- AssertCountExtension
- AtLeastExtension
- AtMostExtension
- AverageExtension
- AwaitAllExtension
- AwaitAnyExtension
- BatchExtension
- BatchSelectExtension
- BetweenExtension
- CartesianExtension
- CartesianSelectExtension
- CompareCountExtension
- ConcatAllExtension
- ConcatExtension
- ConsumeExtension
- CountByExtension
- Deconstruct1Extension
- Deconstruct2Extension
- Deconstruct3Extension
- Deconstruct4Extension
- Deconstruct5Extension
- Deconstruct6Extension
- Deconstruct7Extension
- Deconstruct8Extension
- Deconstruct9Extension
- DefaultIfEmptyExtension
- DefaultRangeIfEmptyExtension
- DistinctExtension
- ElementAtOrDefaultExtension
- EndsWithExtension
- EnumByName
- ExceptExtension
- ExcludeAtExtension
- ExcludeExtension
- ExcludeRangeExtension
- FillBackwardExtension
- FillForwardExtension
- FillMissingExtension
- FirstOrDefaultExtension
- FirstWhereOrDefaultExtension
- FlattenExtension
- FutureIterable
- GroupByExtension
- GroupByValueExtension
- GroupJoinExtension
- GroupSelectExtension
- GroupSelectValueExtension
- IndexExtension
- InsertAllExtension
- InsertExtension
- InsertionIterableExtensions
- InsertOrAppendAll
- InsertOrAppendExtension
- InterleaveAllExtension
- InterleaveExtension
- IntersectExtension
- IterableExtensions
- IterableToJSIterable
- JoinMapExtension
- LagExtension
- LagSelectExtension
- LastOrDefaultExtension
- LastWhereOrDefaultExtension
- LeadExtension
- LeadSelectExtension
- MathConsumerExtensions
- MaxExtension
- MemoizeExtension
- MinExtension
- MoveExtension
- NonNullExtension
- NullableIterableExtensions
- OfTypeExtension
- OrderByDescendingExtension
- OrderByExtension
- PadEndExtension
- PairwiseExtension
- PartitionExtension
- PermutationsExtension
- PrependAllExtension
- PrependExtension
- PreScanExtension
- RandomizeExtension
- RandomSubsetExtension
- RepeatExtension
- ReverseExtension
- ScanExtension
- SelectExtension
- SelectManyExtension
- SequenceEqualsExtension
- SequenceEqualsSelectExtension
- SingleOrDefaultExtension
- SingleWhereOrDefaultExtension
- SkipLastExtension
- SplitExtension
- StartsWithExtension
- SubsetsExtension
- SumExtension
- TakeEveryExtension
- TakeLastExtension
- ThenByDescendingExtension
- ThenByExtension
- ToHashMapExtension
- ToLinkedHashMapExtension
- ToMapExtension
- ToSplayTreeMapExtension
- ToStreamExtension
- TryAggregateExtension
- TryAggregateRightExtension
- TryInsertAllExtension
- TryInsertExtension
- TrySingleOrDefaultExtension
- TrySingleWhereOrDefaultExtension
- UnionExtension
- ZipExtension
Constructors
- Tuple9(T0 item0, T1 item1, T2 item2, T3 item3, T4 item4, T5 item5, T6 item6, T7 item7, T8 item8)
-
Creates a tuple of length 9.
const
-
Tuple9.fromJson(Map<
String, dynamic> map) -
Creates an tuple from a map/JSON source.
factory
- Tuple9.fromList(List list, [bool trim = false])
-
Creates an tuple from a list source.
factory
- Tuple9.fromRecord((T0, T1, T2, T3, T4, T5, T6, T7, T8) record)
-
Creates a tuple from a record.
factory
Properties
- first → dynamic
-
The first element.
no setterinherited
- firstOrNull → T?
-
Available on Iterable<
The first element of this iterator, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - hashCode → int
-
The hash code for this object.
no setteroverride
-
indexed
→ Iterable<
(int, T)> -
Available on Iterable<
Pairs of elements of the indices and elements of this iterable.T> , provided by the IterableExtensions extensionno setter - isEmpty → bool
-
Whether this collection has no elements.
no setterinherited
- isNotEmpty → bool
-
Whether this collection has at least one element.
no setterinherited
- item0 → T0
-
final
- item1 → T1
-
final
- item2 → T2
-
final
- item3 → T3
-
final
- item4 → T4
-
final
- item5 → T5
-
final
- item6 → T6
-
final
- item7 → T7
-
final
- item8 → T8
-
final
- iterator → Iterator
-
A new
Iteratorthat allows iterating the elements of thisIterable.no setteroverride - last → dynamic
-
The last element.
no setterinherited
- lastOrNull → T?
-
Available on Iterable<
The last element of this iterable, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - length → int
-
Returns the constant length of this tuple.
no setteroverride
-
nonNulls
→ Iterable<
T> -
Available on Iterable<
The non-T?> , provided by the NullableIterableExtensions extensionnullelements of this iterable.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- single → dynamic
-
Checks that this iterable has only one element, and returns that element.
no setterinherited
- singleOrNull → T?
-
Available on Iterable<
The single element of this iterator, orT> , provided by the IterableExtensions extensionnull.no setter -
toJSIterable
→ JSIterable<
T> -
Available on Iterable<
A JSIterable wrapper that proxies to the Dart iterable API.T> , provided by the IterableToJSIterable extensionno setter -
wait
→ Future<
List< T> > -
Available on Iterable<
Waits for futures in parallel.Future< , provided by the FutureIterable extensionT> >no setter
Methods
-
aggregate(
T aggregator(T aggregate, T select)) → T -
Available on Iterable<
Aggregates the iterable into a single value.T> , provided by the AggregateExtension extension -
aggregateRight(
T aggregator(T aggregate, T element)) → T -
Available on Iterable<
Aggregates the iterable into a single value in a right-associative manner.T> , provided by the AggregateRightExtension extension -
aggregateRightSelect<
TResult> (TResult initialValue, TResult aggregator(TResult aggregate, T element)) → TResult -
Available on Iterable<
Aggregates the iterable into a single value in a right-associative manner.T> , provided by the AggregateRightSelectExtension extension -
aggregateSelect<
TResult> (TResult initialValue, TResult aggregator(TResult aggregate, T element)) → TResult -
Available on Iterable<
Aggregates the iterable into a single value.T> , provided by the AggregateSelectExtension extension -
all(
[bool condition(T element)?]) → bool -
Available on Iterable<
ReturnsT> , provided by the AllExtension extensiontrueif all elements match a condition andfalseotherwise. -
any(
bool test(dynamic element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
append(
T value) → Iterable< T> -
Available on Iterable<
Inserts an element to the end of the iterable.T> , provided by the AppendExtension extension -
append2(
T v1, T v2) → Iterable< T> -
Available on Iterable<
Inserts two elements to the end of the iterable.T> , provided by the AppendExtension extension -
append3(
T v1, T v2, T v3) → Iterable< T> -
Available on Iterable<
Inserts three elements to the end of the iterable.T> , provided by the AppendExtension extension -
append4(
T v1, T v2, T v3, T v4) → Iterable< T> -
Available on Iterable<
Inserts four elements to the end of the iterable.T> , provided by the AppendExtension extension -
append5(
T v1, T v2, T v3, T v4, T v5) → Iterable< T> -
Available on Iterable<
Inserts five elements to the end of the iterable.T> , provided by the AppendExtension extension -
append6(
T v1, T v2, T v3, T v4, T v5, T v6) → Iterable< T> -
Available on Iterable<
Inserts six elements to the end of the iterable.T> , provided by the AppendExtension extension -
append7(
T v1, T v2, T v3, T v4, T v5, T v6, T v7) → Iterable< T> -
Available on Iterable<
Inserts seven elements to the end of the iterable.T> , provided by the AppendExtension extension -
append8(
T v1, T v2, T v3, T v4, T v5, T v6, T v7, T v8) → Iterable< T> -
Available on Iterable<
Inserts eight elements to the end of the iterable.T> , provided by the AppendExtension extension -
append9(
T v1, T v2, T v3, T v4, T v5, T v6, T v7, T v8, T v9) → Iterable< T> -
Available on Iterable<
Inserts nine elements to the end of the iterable.T> , provided by the AppendExtension extension -
appendAll(
Iterable< T> other) → Iterable<T> -
Available on Iterable<
Inserts all elements in an iterable at the end of this iterable.T> , provided by the AppendAllExtension extension -
asDynamic(
) → Tuple9 - Clones this tuple where the clone is cast with dynamically-typed items.
-
asNameMap(
) → Map< String, T> -
Available on Iterable<
Creates a map from the names of enum values to the values.T> , provided by the EnumByName extension -
assertAll(
bool condition(T element), [String? message]) → Iterable< T> -
Available on Iterable<
Asserts that all elements in this iterable meet a given condition. If not, an AssertionError is thrown.T> , provided by the AssertAllExtension extension -
assertAny(
bool condition(T element), [String? message]) → Iterable< T> -
Available on Iterable<
Asserts that any elements in this iterable meet a given condition. If not, an AssertionError is thrown.T> , provided by the AssertAnyExtension extension -
assertCount(
int count, [String? message]) → Iterable< T> -
Available on Iterable<
Asserts that any elements in this iterable meet a given condition. If not, an AssertionError is thrown.T> , provided by the AssertCountExtension extension -
asType<
U0, U1, U2, U3, U4, U5, U6, U7, U8> () → Tuple9< U0, U1, U2, U3, U4, U5, U6, U7, U8> - Clones this tuple where the clone is cast with the specified type arguments.
-
atLeast(
T value, {int sorter(T element, T value)?}) → bool -
Available on Iterable<
Returns true if all elements in the iterable are equal to or greater thanT> , provided by the AtLeastExtension extensionvalue. -
atMost(
T value, {int sorter(T element, T value)?}) → bool -
Available on Iterable<
Returns true if all elements in the iterable are equal to or less thanT> , provided by the AtMostExtension extensionvalue. -
average<
TNum extends num> ([TNum selector(T value)?]) → TNum -
Available on Iterable<
Calculates the average of all numerical values in the iterable.T> , provided by the AverageExtension extension -
awaitAll(
) → Future< Iterable< T> > -
Available on Iterable<
Awaits each future in the iterable and returns an iterable of the returned values once all the futures have completed.Future< , provided by the AwaitAllExtension extensionT> > -
awaitAny(
) → Future< T> -
Available on Iterable<
Awaits each future in the iterable and returns the value of the first future to complete.Future< , provided by the AwaitAnyExtension extensionT> > -
batch(
int size, {bool includeTail = false}) → Iterable< Iterable< T> > -
Available on Iterable<
Groups elements in the iterator into batches ofT> , provided by the BatchExtension extensionsizelength, optionally truncating elements that don't fit into a full-size batch. -
batchSelect<
TResult> (int size, TResult selector(List< T> batch), {bool includeTail = false}) → Iterable<TResult> -
Available on Iterable<
Groups elements in the iterator into batches ofT> , provided by the BatchSelectExtension extensionsizelength and puts them through a mapping function, optionally truncating elements that don't fit into a full-size batch. -
between(
T minimum, T maximum, {int sorter(T value, T element)?, bool minimumInclusive = false, bool maximumInclusive = false}) → bool -
Available on Iterable<
Returns true if all elements in the iterable are betweenT> , provided by the BetweenExtension extensionminimumandmaximum. -
byName(
String name) → T -
Available on Iterable<
Finds the enum value in this list with nameT> , provided by the EnumByName extensionname. -
cartesian<
T2> (Iterable< T2> other) → Iterable<Tuple2< T, T2> > -
Available on Iterable<
Generates the cartesian product of this iterable andT> , provided by the CartesianExtension extensionother. -
cartesian3<
T2, T3> (Iterable< T2> o2, Iterable<T3> o3) → Iterable<Tuple3< T, T2, T3> > -
Available on Iterable<
Generates the cartesian product of this iterable and two other iterables.T> , provided by the CartesianExtension extension -
cartesian4<
T2, T3, T4> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4) → Iterable<Tuple4< T, T2, T3, T4> > -
Available on Iterable<
Generates the cartesian product of this iterable and three other iterables.T> , provided by the CartesianExtension extension -
cartesian5<
T2, T3, T4, T5> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4, Iterable<T5> o5) → Iterable<Tuple5< T, T2, T3, T4, T5> > -
Available on Iterable<
Generates the cartesian product of this iterable and four other iterables.T> , provided by the CartesianExtension extension -
cartesian6<
T2, T3, T4, T5, T6> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4, Iterable<T5> o5, Iterable<T6> o6) → Iterable<Tuple6< T, T2, T3, T4, T5, T6> > -
Available on Iterable<
Generates the cartesian product of this iterable and five other iterables.T> , provided by the CartesianExtension extension -
cartesian7<
T2, T3, T4, T5, T6, T7> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4, Iterable<T5> o5, Iterable<T6> o6, Iterable<T7> o7) → Iterable<Tuple7< T, T2, T3, T4, T5, T6, T7> > -
Available on Iterable<
Generates the cartesian product of this iterable and six other iterables.T> , provided by the CartesianExtension extension -
cartesian8<
T2, T3, T4, T5, T6, T7, T8> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4, Iterable<T5> o5, Iterable<T6> o6, Iterable<T7> o7, Iterable<T8> o8) → Iterable<Tuple8< T, T2, T3, T4, T5, T6, T7, T8> > -
Available on Iterable<
Generates the cartesian product of this iterable and seven other iterables.T> , provided by the CartesianExtension extension -
cartesian9<
T2, T3, T4, T5, T6, T7, T8, T9> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4, Iterable<T5> o5, Iterable<T6> o6, Iterable<T7> o7, Iterable<T8> o8, Iterable<T9> o9) → Iterable<Tuple9< T, T2, T3, T4, T5, T6, T7, T8, T9> > -
Available on Iterable<
Generates the cartesian product of this iterable and eight other iterables.T> , provided by the CartesianExtension extension -
cartesianSelect<
T2, TResult> (Iterable< T2> other, TResult selector(T element, T2 otherElement)) → Iterable<TResult> -
Available on Iterable<
Generates the cartesian product of this iterable andT> , provided by the CartesianSelectExtension extensionother, returning an iterable of mapped elements. -
cartesianSelect3<
T2, T3, TResult> (Iterable< T2> o2, Iterable<T3> o3, TResult selector(T element, T2 o2Element, T3 o3Element)) → Iterable<TResult> -
Available on Iterable<
Generates the cartesian product of this iterable and two other iterables, returning an iterable of mapped elements.T> , provided by the CartesianSelectExtension extension -
cartesianSelect4<
T2, T3, T4, TResult> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4, TResult selector(T element, T2 o2Element, T3 o3Element, T4 o4Element)) → Iterable<TResult> -
Available on Iterable<
Generates the cartesian product of this iterable and three other iterables, returning an iterable of mapped elements.T> , provided by the CartesianSelectExtension extension -
cartesianSelect5<
T2, T3, T4, T5, TResult> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4, Iterable<T5> o5, TResult selector(T element, T2 o2Element, T3 o3Element, T4 o4Element, T5 o5Element)) → Iterable<TResult> -
Available on Iterable<
Generates the cartesian product of this iterable and four other iterables, returning an iterable of mapped elements.T> , provided by the CartesianSelectExtension extension -
cartesianSelect6<
T2, T3, T4, T5, T6, TResult> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4, Iterable<T5> o5, Iterable<T6> o6, TResult selector(T element, T2 o2Element, T3 o3Element, T4 o4Element, T5 o5Element, T6 o6Element)) → Iterable<TResult> -
Available on Iterable<
Generates the cartesian product of this iterable and five other iterables, returning an iterable of mapped elements.T> , provided by the CartesianSelectExtension extension -
cartesianSelect7<
T2, T3, T4, T5, T6, T7, TResult> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4, Iterable<T5> o5, Iterable<T6> o6, Iterable<T7> o7, TResult selector(T element, T2 o2Element, T3 o3Element, T4 o4Element, T5 o5Element, T6 o6Element, T7 o7Element)) → Iterable<TResult> -
Available on Iterable<
Generates the cartesian product of this iterable and six other iterables, returning an iterable of mapped elements.T> , provided by the CartesianSelectExtension extension -
cartesianSelect8<
T2, T3, T4, T5, T6, T7, T8, TResult> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4, Iterable<T5> o5, Iterable<T6> o6, Iterable<T7> o7, Iterable<T8> o8, TResult selector(T element, T2 o2Element, T3 o3Element, T4 o4Element, T5 o5Element, T6 o6Element, T7 o7Element, T8 o8Element)) → Iterable<TResult> -
Available on Iterable<
Generates the cartesian product of this iterable and seven other iterables, returning an iterable of mapped elements.T> , provided by the CartesianSelectExtension extension -
cartesianSelect9<
T2, T3, T4, T5, T6, T7, T8, T9, TResult> (Iterable< T2> o2, Iterable<T3> o3, Iterable<T4> o4, Iterable<T5> o5, Iterable<T6> o6, Iterable<T7> o7, Iterable<T8> o8, Iterable<T9> o9, TResult selector(T element, T2 o2Element, T3 o3Element, T4 o4Element, T5 o5Element, T6 o6Element, T7 o7Element, T8 o8Element, T9 o9Element)) → Iterable<TResult> -
Available on Iterable<
Generates the cartesian product of this iterable and eight other iterables, returning an iterable of mapped elements.T> , provided by the CartesianSelectExtension extension -
cast<
R> () → Iterable< R> -
A view of this iterable as an iterable of
Rinstances.inherited -
compareCount(
Iterable other) → int -
Available on Iterable<
Compares the length of this iterable andT> , provided by the CompareCountExtension extensionotherand returns an integer representing their comparison. -
concat(
Iterable< T> other) → Iterable<T> -
Available on Iterable<
Concatenates this iterable and another iterables.T> , provided by the ConcatExtension extension -
concat2(
Iterable< T> c1, Iterable<T> c2) → Iterable<T> -
Available on Iterable<
Concatenates this iterable and two another iterables.T> , provided by the ConcatExtension extension -
concat3(
Iterable< T> c1, Iterable<T> c2, Iterable<T> c3) → Iterable<T> -
Available on Iterable<
Concatenates this iterable and three another iterables.T> , provided by the ConcatExtension extension -
concat4(
Iterable< T> c1, Iterable<T> c2, Iterable<T> c3, Iterable<T> c4) → Iterable<T> -
Available on Iterable<
Concatenates this iterable and four another iterables.T> , provided by the ConcatExtension extension -
concat5(
Iterable< T> c1, Iterable<T> c2, Iterable<T> c3, Iterable<T> c4, Iterable<T> c5) → Iterable<T> -
Available on Iterable<
Concatenates this iterable and five another iterables.T> , provided by the ConcatExtension extension -
concat6(
Iterable< T> c1, Iterable<T> c2, Iterable<T> c3, Iterable<T> c4, Iterable<T> c5, Iterable<T> c6) → Iterable<T> -
Available on Iterable<
Concatenates this iterable and six another iterables.T> , provided by the ConcatExtension extension -
concat7(
Iterable< T> c1, Iterable<T> c2, Iterable<T> c3, Iterable<T> c4, Iterable<T> c5, Iterable<T> c6, Iterable<T> c7) → Iterable<T> -
Available on Iterable<
Concatenates this iterable and seven another iterables.T> , provided by the ConcatExtension extension -
concat8(
Iterable< T> c1, Iterable<T> c2, Iterable<T> c3, Iterable<T> c4, Iterable<T> c5, Iterable<T> c6, Iterable<T> c7, Iterable<T> c8) → Iterable<T> -
Available on Iterable<
Concatenates this iterable and eight another iterables.T> , provided by the ConcatExtension extension -
concat9(
Iterable< T> c1, Iterable<T> c2, Iterable<T> c3, Iterable<T> c4, Iterable<T> c5, Iterable<T> c6, Iterable<T> c7, Iterable<T> c8, Iterable<T> c9) → Iterable<T> -
Available on Iterable<
Concatenates this iterable and nine another iterables.T> , provided by the ConcatExtension extension -
concatAll(
Iterable< Iterable< iterables) → Iterable<T> >T> -
Available on Iterable<
Concatenates this iterable and a provided iterable of iterables.T> , provided by the ConcatAllExtension extension -
consume(
) → void -
Available on Iterable<
Fully consumes this iterable.T> , provided by the ConsumeExtension extension -
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.inherited -
copyWith(
{T0? item0, T1? item1, T2? item2, T3? item3, T4? item4, T5? item5, T6? item6, T7? item7, T8? item8}) → Tuple9< T0, T1, T2, T3, T4, T5, T6, T7, T8> - Creates a copy tuple with the elements from this tuple with the value of each item optionally overridden.
-
copyWithout(
{required List< bool> indices}) → Tuple - A list of boolean values indicating whether certain items in this tuple should be retained or discarded. The length of the list must be the same as the length of this tuple.
-
count(
[bool condition(T element)?]) → int -
Available on Iterable<
Returns the number of elements in the iterable.T> , provided by the MathConsumerExtensions extension -
countBy<
TKey> (TKey keySelector(T element)) → Iterable< MapEntry< TKey, int> > -
Available on Iterable<
AppliesT> , provided by the CountByExtension extensionkeySelectorto every element in this iterable and returns an iterable containing each resulting key and the number of times that key appears in this iterable. -
deconstruct(
) → (Iterable< T1> , Iterable<T2> , Iterable<T3> , Iterable<T4> , Iterable<T5> , Iterable<T6> , Iterable<T7> , Iterable<T8> ) -
Available on Iterable<
Takes this iterable of records and deconstructs it into a record of iterables.(T1, T2, T3, T4, T5, T6, T7, T8)> , provided by the Deconstruct8Extension extension -
deconstruct(
) → (Iterable< T1> , Iterable<T2> , Iterable<T3> , Iterable<T4> , Iterable<T5> , Iterable<T6> , Iterable<T7> , Iterable<T8> , Iterable<T9> ) -
Available on Iterable<
Takes this iterable of records and deconstructs it into a record of iterables.(T1, T2, T3, T4, T5, T6, T7, T8, T9)> , provided by the Deconstruct9Extension extension -
deconstruct(
) → (Iterable< T> ) -
Available on Iterable<
Takes this iterable of records and deconstructs it into a record of iterables.(T)> , provided by the Deconstruct1Extension extension -
deconstruct(
) → (Iterable< T1> , Iterable<T2> ) -
Available on Iterable<
Takes this iterable of records and deconstructs it into a record of iterables.(T1, T2)> , provided by the Deconstruct2Extension extension -
deconstruct(
) → (Iterable< T1> , Iterable<T2> , Iterable<T3> ) -
Available on Iterable<
Takes this iterable of records and deconstructs it into a record of iterables.(T1, T2, T3)> , provided by the Deconstruct3Extension extension -
deconstruct(
) → (Iterable< T1> , Iterable<T2> , Iterable<T3> , Iterable<T4> ) -
Available on Iterable<
Takes this iterable of records and deconstructs it into a record of iterables.(T1, T2, T3, T4)> , provided by the Deconstruct4Extension extension -
deconstruct(
) → (Iterable< T1> , Iterable<T2> , Iterable<T3> , Iterable<T4> , Iterable<T5> ) -
Available on Iterable<
Takes this iterable of records and deconstructs it into a record of iterables.(T1, T2, T3, T4, T5)> , provided by the Deconstruct5Extension extension -
deconstruct(
) → (Iterable< T1> , Iterable<T2> , Iterable<T3> , Iterable<T4> , Iterable<T5> , Iterable<T6> ) -
Available on Iterable<
Takes this iterable of records and deconstructs it into a record of iterables.(T1, T2, T3, T4, T5, T6)> , provided by the Deconstruct6Extension extension -
deconstruct(
) → (Iterable< T1> , Iterable<T2> , Iterable<T3> , Iterable<T4> , Iterable<T5> , Iterable<T6> , Iterable<T7> ) -
Available on Iterable<
Takes this iterable of records and deconstructs it into a record of iterables.(T1, T2, T3, T4, T5, T6, T7)> , provided by the Deconstruct7Extension extension -
defaultIfEmpty(
T defaultVal) → Iterable< T> -
Available on Iterable<
Returns a new iterable containingT> , provided by the DefaultIfEmptyExtension extensiondefaultValif this iterable is empty. Otherwise, the source iterable will be unaffected. -
defaultRangeIfEmpty(
Iterable< T> defaultVal) → Iterable<T> -
Available on Iterable<
Returns this iterable, orT> , provided by the DefaultRangeIfEmptyExtension extensiondefaultValif this iterable is empty. -
distinct(
[Object keySelector(T element)?]) → Iterable< T> -
Available on Iterable<
Returns an iterable representing the distinct values of this iterable.T> , provided by the DistinctExtension extension -
elementAt(
int index) → dynamic -
Returns the
indexth element.inherited -
elementAtOrDefault(
int index, {required T defaultValue}) → T -
Available on Iterable<
Returns the element at the specified index or a default value of one is not found.T> , provided by the ElementAtOrDefaultExtension extension -
elementAtOrNull(
int index) → T? -
Available on Iterable<
The element at positionT> , provided by the IterableExtensions extensionindexof this iterable, ornull. -
endsWith(
Iterable< T> other, {bool comparer(T value, T otherValue)?}) → bool -
Available on Iterable<
Returns true if this iterable ends with the same elements that are inT> , provided by the EndsWithExtension extensionother. -
every(
bool test(dynamic element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
except(
Iterable< T> other, [Object selector(T element)?]) → Iterable<T> -
Available on Iterable<
Returns the set difference between the iterable and the given collection.T> , provided by the ExceptExtension extension -
exclude(
T value, {bool comparer(T value, T element)?}) → Iterable< T> -
Available on Iterable<
Returns all elements in this iterable except those that are equal to the specified value.T> , provided by the ExcludeExtension extension -
excludeAt(
int index) → Iterable< T> -
Available on Iterable<
Returns all elements in this iterable except the element atT> , provided by the ExcludeAtExtension extensionindex. -
excludeRange(
int start, int count) → Iterable< T> -
Available on Iterable<
Returns all elements in this iterable except those that are within the specified range.T> , provided by the ExcludeRangeExtension extension -
expand<
T> (Iterable< T> toElements(dynamic element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
fillBackward(
) → Iterable< T> -
Available on Iterable<
Returns this iterable with all null values replaced with the next non-null element following it.T?> , provided by the FillBackwardExtension extension -
fillForward(
) → Iterable< T> -
Available on Iterable<
Returns this iterable with all null values replaced with the first non-null element preceeding it.T?> , provided by the FillForwardExtension extension -
fillMissing(
T value) → Iterable< T> -
Available on Iterable<
Returns this iterable with all null values replaced with the specified value.T?> , provided by the FillMissingExtension extension -
firstOrDefault(
{T? defaultValue}) → T? -
Available on Iterable<
Returns the first element in the iterable.T> , provided by the FirstOrDefaultExtension extension -
firstWhere(
bool test(dynamic element), {dynamic orElse()?}) → dynamic -
The first element that satisfies the given predicate
test.inherited -
firstWhereOrDefault(
bool condition(T value), {T? defaultValue}) → T? -
Available on Iterable<
Returns the first element in the iterable matching a specified condition, or a default value if none is found.T> , provided by the FirstWhereOrDefaultExtension extension -
flatten(
) → Iterable< T> -
Available on Iterable<
Flattens this iterable of iterables into a single iterable.Iterable< , provided by the FlattenExtension extensionT> > -
fold<
T> (T initialValue, T combine(T previousValue, dynamic element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
followedBy(
Iterable other) → Iterable -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void action(dynamic element)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
groupBy<
TKey> (TKey keySelector(T element), {EqualityComparer< TKey> ? keyComparer}) → GroupByIterable<T, TKey> -
Available on Iterable<
Groups the elements in the iterable by a key.T> , provided by the GroupByExtension extension -
groupByValue<
TKey, TValue> ({TKey keySelector(T element)?, TValue valueSelector(T element)?, EqualityComparer< TKey> ? keyComparer}) → GroupByValueIterable<T, TKey, TValue> -
Available on Iterable<
Groups the elements in the iterable by a key and maps the elements to a new value.T> , provided by the GroupByValueExtension extension -
groupJoin<
TInner, TKey, TResult> (Iterable< TInner> inner, TResult resultSelector(T element, Iterable<TInner> other), {TKey outerKeySelector(T element)?, TKey innerKeySelector(TInner otherElement)?, EqualityComparer<TKey> ? keyComparer}) → GroupJoinIterable<T, TInner, TKey, TResult> -
Available on Iterable<
Joins elements in the iterable with a group of all elements in theT> , provided by the GroupJoinExtension extensioninnercollection that match the generated key. -
groupSelect<
TKey, TResult> (TResult resultSelector(TKey key, Iterable< T> group), {TKey keySelector(T key)?, EqualityComparer<TKey> ? keyComparer}) → GroupSelectIterable<T, TKey, TResult> -
Available on Iterable<
Groups the elements in the iterable by a key and maps the groups to a new element.T> , provided by the GroupSelectExtension extension -
groupSelectValue<
TKey, TValue, TResult> (TResult resultSelector(TKey key, Iterable< TValue> group), {TKey keySelector(T element)?, TValue valueSelector(T element)?, EqualityComparer<TKey> ? keyComparer}) → GroupSelectValueIterable<T, TKey, TValue, TResult> -
Available on Iterable<
Groups the elements in the iterable by a key, maps the elements to a new value, and maps the groups to a new element.T> , provided by the GroupSelectValueExtension extension -
index(
[int startIndex = 0, bool descending = false]) → Iterable< MapEntry< int, T> > -
Available on Iterable<
Returns an iterable of MapEntry representing the elements in this iterable combined with the zero-based index where the element was found.T> , provided by the IndexExtension extension -
insert(
int index, T value) → Iterable< T> -
Available on Iterable<
Inserts an element into the iterable at the specified index.T> , provided by the InsertExtension extension -
insert2(
int index, T v1, T v2) → Iterable< T> -
Available on Iterable<
Inserts two elements into the iterable at the specified index.T> , provided by the InsertExtension extension -
insert3(
int index, T v1, T v2, T v3) → Iterable< T> -
Available on Iterable<
Inserts three elements into the iterable at the specified index.T> , provided by the InsertExtension extension -
insert4(
int index, T v1, T v2, T v3, T v4) → Iterable< T> -
Available on Iterable<
Inserts four elements into the iterable at the specified index.T> , provided by the InsertExtension extension -
insert5(
int index, T v1, T v2, T v3, T v4, T v5) → Iterable< T> -
Available on Iterable<
Inserts five elements into the iterable at the specified index.T> , provided by the InsertExtension extension -
insert6(
int index, T v1, T v2, T v3, T v4, T v5, T v6) → Iterable< T> -
Available on Iterable<
Inserts six elements into the iterable at the specified index.T> , provided by the InsertExtension extension -
insert7(
int index, T v1, T v2, T v3, T v4, T v5, T v6, T v7) → Iterable< T> -
Available on Iterable<
Inserts seven elements into the iterable at the specified index.T> , provided by the InsertExtension extension -
insert8(
int index, T v1, T v2, T v3, T v4, T v5, T v6, T v7, T v8) → Iterable< T> -
Available on Iterable<
Inserts eight elements into the iterable at the specified index.T> , provided by the InsertExtension extension -
insert9(
int index, T v1, T v2, T v3, T v4, T v5, T v6, T v7, T v8, T v9) → Iterable< T> -
Available on Iterable<
Inserts nine elements into the iterable at the specified index.T> , provided by the InsertExtension extension -
insertAll(
int index, Iterable< T> other) → Iterable<T> -
Available on Iterable<
Inserts all elements from another iterable into this iterable at the specified index.T> , provided by the InsertAllExtension extension -
insertOrAppend(
int index, T value) → Iterable< T> -
Available on Iterable<
Inserts an element into the iterable at the specified index.T> , provided by the InsertOrAppendExtension extension -
insertOrAppend2(
int index, T v1, T v2) → Iterable< T> -
Available on Iterable<
Inserts two elements into the iterable at the specified index.T> , provided by the InsertOrAppendExtension extension -
insertOrAppend3(
int index, T v1, T v2, T v3) → Iterable< T> -
Available on Iterable<
Inserts three elements into the iterable at the specified index.T> , provided by the InsertOrAppendExtension extension -
insertOrAppend4(
int index, T v1, T v2, T v3, T v4) → Iterable< T> -
Available on Iterable<
Inserts four elements into the iterable at the specified index.T> , provided by the InsertOrAppendExtension extension -
insertOrAppend5(
int index, T v1, T v2, T v3, T v4, T v5) → Iterable< T> -
Available on Iterable<
Inserts five elements into the iterable at the specified index.T> , provided by the InsertOrAppendExtension extension -
insertOrAppend6(
int index, T v1, T v2, T v3, T v4, T v5, T v6) → Iterable< T> -
Available on Iterable<
Inserts six elements into the iterable at the specified index.T> , provided by the InsertOrAppendExtension extension -
insertOrAppend7(
int index, T v1, T v2, T v3, T v4, T v5, T v6, T v7) → Iterable< T> -
Available on Iterable<
Inserts seven elements into the iterable at the specified index.T> , provided by the InsertOrAppendExtension extension -
insertOrAppend8(
int index, T v1, T v2, T v3, T v4, T v5, T v6, T v7, T v8) → Iterable< T> -
Available on Iterable<
Inserts eight elements into the iterable at the specified index.T> , provided by the InsertOrAppendExtension extension -
insertOrAppend9(
int index, T v1, T v2, T v3, T v4, T v5, T v6, T v7, T v8, T v9) → Iterable< T> -
Available on Iterable<
Inserts nine elements into the iterable at the specified index.T> , provided by the InsertOrAppendExtension extension -
insertOrAppendAll(
int index, Iterable< T> other) → Iterable<T> -
Available on Iterable<
Inserts all elements from another iterable into this iterable at the specified index.T> , provided by the InsertOrAppendAll extension -
interleave(
Iterable< T> other) → Iterable<T> -
Available on Iterable<
Returns the elements of this iterable interleaved with the elements ofT> , provided by the InterleaveExtension extensionother. -
interleaveAll(
Iterable< Iterable< others) → Iterable<T> >T> -
Available on Iterable<
Returns the elements of this iterable interleaved with the elements of every iterable inT> , provided by the InterleaveAllExtension extensionothers. -
intersect(
Iterable< T> other, [Object selector(T element)?]) → Iterable<T> -
Available on Iterable<
Returns the set intersection between the iterable and the given collection.T> , provided by the IntersectExtension extension -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
joinMap<
TInner, TKey, TResult> (Iterable< TInner> inner, TResult resultSelector(T element, TInner otherElement), {TKey outerKeySelector(T element)?, TKey innerKeySelector(TInner otherElement)?, EqualityComparer<TKey> ? keyComparer}) → Iterable<TResult> -
Available on Iterable<
Finds keys in this iterable with matching keys in theT> , provided by the JoinMapExtension extensioninnercollection and returns a value that is the result of the corresponding elements being merged. -
lag(
int offset, {required T defaultValue}) → Iterable< Iterable< T> > -
Available on Iterable<
Returns an iterable that projects the elements in this iterable upon other elements in this iterable offset backwards by a given value.T> , provided by the LagExtension extension -
lagSelect<
TResult> (int offset, TResult selector(T element, T laggedElement), {required T defaultValue}) → Iterable< TResult> -
Available on Iterable<
Returns an iterable that projects the elements in this iterable upon other elements in this iterable offset backwards by a given value.T> , provided by the LagSelectExtension extension -
lastOrDefault(
{T? defaultValue}) → T? -
Available on Iterable<
Returns the last element in the iterable.T> , provided by the LastOrDefaultExtension extension -
lastWhere(
bool test(dynamic element), {dynamic orElse()?}) → dynamic -
The last element that satisfies the given predicate
test.inherited -
lastWhereOrDefault(
bool condition(T element), {T? defaultValue}) → T? -
Available on Iterable<
Returns the last element in the iterable matching a specified condition, or a default value if none is found.T> , provided by the LastWhereOrDefaultExtension extension -
lead(
int offset, {required T defaultValue}) → Iterable< Iterable< T> > -
Available on Iterable<
Returns an iterable that projects the elements in this iterable upon other elements in this iterable offset forwards by a given value.T> , provided by the LeadExtension extension -
leadSelect<
TResult> (int offset, TResult selector(T leadedElement, T element), {required T defaultValue}) → Iterable< TResult> -
Available on Iterable<
Returns an iterable that projects the elements in this iterable upon other elements in this iterable offset forwards by a given value.T> , provided by the LeadSelectExtension extension -
map<
T> (T toElement(dynamic e)) → Iterable< T> -
The current elements of this iterable modified by
toElement.inherited -
mapActions(
{required void item0(T0), required void item1(T1), required void item2(T2), required void item3(T3), required void item4(T4), required void item5(T5), required void item6(T6), required void item7(T7), required void item8(T8)}) → void - A utility method for mapping a function to every item in this tuple.
-
max(
[int comparer(T e1, T e2)?]) → T -
Available on Iterable<
Returns the maximum value in the iterable.T> , provided by the MaxExtension extension -
memoize(
) → Iterable< T> -
Available on Iterable<
Returns an iterable whose elements are cached during the first iteration.T> , provided by the MemoizeExtension extension -
min(
[int comparer(T e1, T e2)?]) → T -
Available on Iterable<
Returns the minimum value in the iterable.T> , provided by the MinExtension extension -
move(
int from, int count, int to) → Iterable< T> -
Available on Iterable<
Moves a range of elements in this iterable to a new position, offsetting other elements to compensate.T> , provided by the MoveExtension extension -
nonNull(
) → Iterable< T> -
Available on Iterable<
Returns this iterable with all null values excluded.T?> , provided by the NonNullExtension extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
ofType<
TOther> () → Iterable< TOther> -
Available on Iterable<
Returns all elements in the iterable that are castable to the specified type.T> , provided by the OfTypeExtension extension -
ofType2<
T1, T2> () → Iterable< T> -
Available on Iterable<
Returns all elements in the iterable that are castable to one of the specified types.T> , provided by the OfTypeExtension extension -
ofType3<
T1, T2, T3> () → Iterable< T> -
Available on Iterable<
Returns all elements in the iterable that are castable to one of the specified types.T> , provided by the OfTypeExtension extension -
ofType4<
T1, T2, T3, T4> () → Iterable< T> -
Available on Iterable<
Returns all elements in the iterable that are castable to one of the specified types.T> , provided by the OfTypeExtension extension -
ofType5<
T1, T2, T3, T4, T5> () → Iterable< T> -
Available on Iterable<
Returns all elements in the iterable that are castable to one of the specified types.T> , provided by the OfTypeExtension extension -
ofType6<
T1, T2, T3, T4, T5, T6> () → Iterable< T> -
Available on Iterable<
Returns all elements in the iterable that are castable to one of the specified types.T> , provided by the OfTypeExtension extension -
ofType7<
T1, T2, T3, T4, T5, T6, T7> () → Iterable< T> -
Available on Iterable<
Returns all elements in the iterable that are castable to one of the specified types.T> , provided by the OfTypeExtension extension -
ofType8<
T1, T2, T3, T4, T5, T6, T7, T8> () → Iterable< T> -
Available on Iterable<
Returns all elements in the iterable that are castable to one of the specified types.T> , provided by the OfTypeExtension extension -
ofType9<
T1, T2, T3, T4, T5, T6, T7, T8, T9> () → Iterable< T> -
Available on Iterable<
Returns all elements in the iterable that are castable to one of the specified types.T> , provided by the OfTypeExtension extension -
orderBy<
TKey> (TKey keySelector(T element), {EqualityComparer< TKey> ? keyComparer}) → Iterable<T> -
Available on Iterable<
Sorts the iteration in ascending (least-to-greatest) order.T> , provided by the OrderByExtension extension -
orderByDescending<
TKey> (TKey keySelector(T element), {EqualityComparer< TKey> ? keyComparer}) → Iterable<T> -
Available on Iterable<
Sorts the iteration in descending (greatest-to-least) order.T> , provided by the OrderByDescendingExtension extension -
padEnd(
int length, {required T padding}) → Iterable< T> -
Available on Iterable<
Pads the iterable to be at leastT> , provided by the PadEndExtension extensionlength, addingpaddingto the end as needed to guarantee the length. -
padStart(
int length, {required T padding}) → Iterable< T> -
Available on Iterable<
Pads the iterable to be at leastT> , provided by the InsertionIterableExtensions extensionlength, addingpaddingto the start as needed to guarantee the length. -
pairwise(
) → Iterable< Tuple2< T, T> > -
Available on Iterable<
Returns an iterable that pairs every element with the element before it.T> , provided by the PairwiseExtension extension -
partition(
bool condition(T element)) → Iterable< Iterable< T> > -
Available on Iterable<
Returns an iterable containing two iterables, one containing the elements that match the condition and one containing those that do not.T> , provided by the PartitionExtension extension -
permutations(
) → Iterable< Iterable< T> > -
Available on Iterable<
Returns an iterable that consists of iterables, where each iterable is a collection of all the permutations of the elements in this iterable.T> , provided by the PermutationsExtension extension -
prepend(
T value) → Iterable< T> -
Available on Iterable<
Inserts an element at the beginning of the iterable.T> , provided by the PrependExtension extension -
prepend2(
T v1, T v2) → Iterable< T> -
Available on Iterable<
Inserts two elements at the beginning of the iterable.T> , provided by the PrependExtension extension -
prepend3(
T v1, T v2, T v3) → Iterable< T> -
Available on Iterable<
Inserts three elements at the beginning of the iterable.T> , provided by the PrependExtension extension -
prepend4(
T v1, T v2, T v3, T v4) → Iterable< T> -
Available on Iterable<
Inserts four elements at the beginning of the iterable.T> , provided by the PrependExtension extension -
prepend5(
T v1, T v2, T v3, T v4, T v5) → Iterable< T> -
Available on Iterable<
Inserts five elements at the beginning of the iterable.T> , provided by the PrependExtension extension -
prepend6(
T v1, T v2, T v3, T v4, T v5, T v6) → Iterable< T> -
Available on Iterable<
Inserts six elements at the beginning of the iterable.T> , provided by the PrependExtension extension -
prepend7(
T v1, T v2, T v3, T v4, T v5, T v6, T v7) → Iterable< T> -
Available on Iterable<
Inserts seven elements at the beginning of the iterable.T> , provided by the PrependExtension extension -
prepend8(
T v1, T v2, T v3, T v4, T v5, T v6, T v7, T v8) → Iterable< T> -
Available on Iterable<
Inserts eight elements at the beginning of the iterable.T> , provided by the PrependExtension extension -
prepend9(
T v1, T v2, T v3, T v4, T v5, T v6, T v7, T v8, T v9) → Iterable< T> -
Available on Iterable<
Inserts nine elements at the beginning of the iterable.T> , provided by the PrependExtension extension -
prependAll(
Iterable< T> other) → Iterable<T> -
Available on Iterable<
Inserts all elements in an iterable at the beginning of this iterable.T> , provided by the PrependAllExtension extension -
preScan(
T initialValue, T aggregator(T value, T element)) → Iterable< T> -
Available on Iterable<
Returns the pre-scan (exclusive prefix sum) of this iterable.T> , provided by the PreScanExtension extension -
randomize(
[Random? random]) → Iterable< T> -
Available on Iterable<
Returns a sequence of elements in random order from the original sequence. The optional parameterT> , provided by the RandomizeExtension extensionrandomspecifies a random generator to be used for the random selection algorithm. -
randomSubset(
int size, [Random? random]) → Iterable< T> -
Available on Iterable<
Returns an iterable of the specified size consisting of random elements from this iterable. The optional parameterT> , provided by the RandomSubsetExtension extensionrandomspecifies a random generator to be used for the random selection algorithm. -
reduce(
dynamic combine(dynamic value, dynamic element)) → dynamic -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
repeat(
int count) → Iterable< T> -
Available on Iterable<
Repeats this iterable a specified number of times.T> , provided by the RepeatExtension extension -
reverse(
) → Iterable< T> -
Available on Iterable<
Reverses the order of the iterable.T> , provided by the ReverseExtension extension -
scan(
T aggregator(T previousElement, T element)) → Iterable< T> -
Available on Iterable<
Returns the scan (inclusive prefix sum) of this iterable.T> , provided by the ScanExtension extension -
select<
TResult> (TResult selector(T element, int index)) → Iterable< TResult> -
Available on Iterable<
Applies a mapping function to the elements in the iterable, including the index where each element is found.T> , provided by the SelectExtension extension -
selectMany<
TResult> (Iterable< TResult> selector(T element, int index)) → Iterable<TResult> -
Available on Iterable<
Maps elements in an iterable to collections and then flattens those collections into a single iterable.T> , provided by the SelectManyExtension extension -
sequenceEquals(
Iterable< T> other, {bool comparer(T outer, T inner)?}) → bool -
Available on Iterable<
ReturnsT> , provided by the SequenceEqualsExtension extensiontrueif this iterable is equivalent to the given collection. -
sequenceEqualsSelect<
TOther, TKey> (Iterable< TOther> other, {required TKey outerSelector(T element)?, required TKey innerSelector(TOther element)?, bool comparer(TKey outer, TKey inner)?}) → bool -
Available on Iterable<
ReturnsT> , provided by the SequenceEqualsSelectExtension extensiontrueif this iterable is equivalent to the given collection. -
singleOrDefault(
{required T defaultValue}) → T -
Available on Iterable<
Returns the single element in the iterable, or aT> , provided by the SingleOrDefaultExtension extensiondefaultValueif no such element exists. -
singleWhere(
bool test(dynamic element), {dynamic orElse()?}) → dynamic -
The single element that satisfies
test.inherited -
singleWhereOrDefault(
bool condition(T element), {required T defaultValue}) → T -
Available on Iterable<
Returns the single element in the iterable matching aT> , provided by the SingleWhereOrDefaultExtension extensioncondition, or adefaultValueif no such element exists. -
skip(
int count) → Iterable -
Creates an Iterable that provides all but the first
countelements.inherited -
skipLast(
int count) → Iterable< T> -
Available on Iterable<
Skips the lastT> , provided by the SkipLastExtension extensioncountelements in an iterable. -
skipWhile(
bool test(dynamic element)) → Iterable -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
split(
T separator, {bool comparer(T separator, T element)?}) → Iterable< Iterable< T> > -
Available on Iterable<
Splits the is iterable into multiple iterables on elements that match the separator.T> , provided by the SplitExtension extension -
startsWith(
Iterable< T> other, {bool comparer(T otherElement, T element)?}) → bool -
Available on Iterable<
Returns true if this iterable starts with the same elements that are inT> , provided by the StartsWithExtension extensionother. -
subsets(
) → Iterable< Iterable< T> > -
Available on Iterable<
Returns an iterable of iterables which represents all of the subsets of this iterable. (Also known as the power set of the iterable.)T> , provided by the SubsetsExtension extension -
sum<
TNum extends num> ([TNum selector(T)?]) → TNum -
Available on Iterable<
Calculates the sum of the elements in an iterable, optionally usingT> , provided by the SumExtension extensionselectorto obtain the value to be summed. -
swap(
List< T> input, int a, int b) → void -
Available on Iterable<
T> , provided by the PermutationsExtension extension -
take(
int count) → Iterable -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeEvery(
int step) → Iterable< T> -
Available on Iterable<
Takes every N-th element in this iterable.T> , provided by the TakeEveryExtension extension -
takeLast(
int count) → Iterable< T> -
Available on Iterable<
Takes the lastT> , provided by the TakeLastExtension extensioncountelements in an iterable. -
takeWhile(
bool test(dynamic element)) → Iterable -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
thenBy<
TKey> (TKey keySelector(T element), {EqualityComparer< TKey> ? keyComparer}) → Iterable<T> -
Available on Iterable<
Adds a secondary sorting pass to iteration in ascending (least-to-greatest) order.T> , provided by the ThenByExtension extension -
thenByDescending<
TKey> (TKey keySelector(T element), {EqualityComparer< TKey> ? keyComparer}) → Iterable<T> -
Available on Iterable<
Adds a secondary sorting pass to iteration in ascending (least-to-greatest) order.T> , provided by the ThenByDescendingExtension extension -
toHashMap<
TKey, TValue> (MapEntry< TKey, TValue> entrySelector(T element), {bool modifiable = true}) → Map<TKey, TValue> -
Available on Iterable<
Converts the iterable to a HashMap.T> , provided by the ToHashMapExtension extension -
toJson(
) → Map< String, dynamic> - Converts this tuple into a map for JSON serialization.
-
toLinkedHashMap<
TKey, TValue> (MapEntry< TKey, TValue> entrySelector(T element), {bool modifiable = true}) → Map<TKey, TValue> -
Available on Iterable<
Converts the iterable to a LinkedHashMap.T> , provided by the ToLinkedHashMapExtension extension -
toList(
{bool growable = true}) → List -
Creates a List containing the elements of this Iterable.
inherited
-
toMap<
TKey, TValue> (MapEntry< TKey, TValue> entrySelector(T element), {bool modifiable = false}) → Map<TKey, TValue> -
Available on Iterable<
Converts the iterable to a Map.T> , provided by the ToMapExtension extension -
toRecord(
) → (T0, T1, T2, T3, T4, T5, T6, T7, T8) - Converts this tuple into a record.
-
toSet(
) → Set -
Creates a Set containing the same elements as this iterable.
inherited
-
toSplayTreeMap<
TKey, TValue> (MapEntry< TKey, TValue> entrySelector(T element), {int keyComparer(TKey k1, TKey k2)?, bool modifiable = true}) → Map<TKey, TValue> -
Available on Iterable<
Converts the iterable to a SplayTreeMap.T> , provided by the ToSplayTreeMapExtension extension -
toStream(
{bool isBroadcast = false}) → Stream< T> -
Available on Iterable<
Converts the iterable to a Stream.T> , provided by the ToStreamExtension extension -
toString(
) → String -
Returns a string representation of (some of) the elements of
this.override -
tryAggregate(
T aggregator(T aggregate, T element), {T? defaultValue}) → T? -
Available on Iterable<
Aggregates the iterable into a single value.T> , provided by the TryAggregateExtension extension -
tryAggregateRight(
T aggregator(T aggregate, T element), {T? defaultValue}) → T? -
Available on Iterable<
Aggregates the iterable into a single value in a right-associative manner.T> , provided by the TryAggregateRightExtension extension -
tryInsert(
int index, T value) → Iterable< T> -
Available on Iterable<
Inserts an element into the iterable at the specified index.T> , provided by the TryInsertExtension extension -
tryInsert2(
int index, T v1, T v2) → Iterable< T> -
Available on Iterable<
Inserts two elements into the iterable at the specified index.T> , provided by the TryInsertExtension extension -
tryInsert3(
int index, T v1, T v2, T v3) → Iterable< T> -
Available on Iterable<
Inserts three elements into the iterable at the specified index.T> , provided by the TryInsertExtension extension -
tryInsert4(
int index, T v1, T v2, T v3, T v4) → Iterable< T> -
Available on Iterable<
Inserts four elements into the iterable at the specified index.T> , provided by the TryInsertExtension extension -
tryInsert5(
int index, T v1, T v2, T v3, T v4, T v5) → Iterable< T> -
Available on Iterable<
Inserts five elements into the iterable at the specified index.T> , provided by the TryInsertExtension extension -
tryInsert6(
int index, T v1, T v2, T v3, T v4, T v5, T v6) → Iterable< T> -
Available on Iterable<
Inserts six elements into the iterable at the specified index.T> , provided by the TryInsertExtension extension -
tryInsert7(
int index, T v1, T v2, T v3, T v4, T v5, T v6, T v7) → Iterable< T> -
Available on Iterable<
Inserts seven elements into the iterable at the specified index.T> , provided by the TryInsertExtension extension -
tryInsert8(
int index, T v1, T v2, T v3, T v4, T v5, T v6, T v7, T v8) → Iterable< T> -
Available on Iterable<
Inserts eight elements into the iterable at the specified index.T> , provided by the TryInsertExtension extension -
tryInsert9(
int index, T v1, T v2, T v3, T v4, T v5, T v6, T v7, T v8, T v9) → Iterable< T> -
Available on Iterable<
Inserts nine elements into the iterable at the specified index.T> , provided by the TryInsertExtension extension -
tryInsertAll(
int index, Iterable< T> other) → Iterable<T> -
Available on Iterable<
Inserts an element into the iterable at the specified index.T> , provided by the TryInsertAllExtension extension -
trySingleOrDefault(
{T? defaultValue}) → T? -
Available on Iterable<
Returns the single element in the iterable, or aT> , provided by the TrySingleOrDefaultExtension extensiondefaultValueif no such element exists. -
trySingleWhereOrDefault(
bool condition(T element), {T? defaultValue}) → T? -
Available on Iterable<
Returns the single element in the iterable matching aT> , provided by the TrySingleWhereOrDefaultExtension extensioncondition, or adefaultValueif no such element exists. -
union(
Iterable< T> other, [Object selector(T element)?]) → Iterable<T> -
Available on Iterable<
Returns the set union between the iterable and the given collection.T> , provided by the UnionExtension extension -
where(
bool test(dynamic element)) → Iterable -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereType<
T> () → Iterable< R> -
Creates a new lazy Iterable with all elements that have type
T.inherited -
zip<
TOther, TResult> (Iterable< TOther> other, TResult selector(T element, TOther otherElement)) → Iterable<TResult> -
Available on Iterable<
Combines the values of the iterable and another collection into an iterable of new values.T> , provided by the ZipExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
-
operator [](
int index) → dynamic - Provides an indexable way to access this tuple's items.